.. image:: https://img.shields.io/pypi/v/airfoils.svg?style=flat
   :target: https://pypi.org/project/airfoils/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/badge/license-Apache%202-blue.svg
    :target: https://github.com/airinnova/framat/blob/master/LICENSE.txt
    :alt: License

.. code::

    pip install airfoils

License
-------

**License:** Apache-2.0
